@@ -26,10 +26,16 @@ class TerraformParser(object):
             '0.14.',
             '0.15.',
             '1.0.',
+            '1.1.',
+            '1.2.',
+            '1.3.',
         )
         self.supported_format_versions = [
             '0.1',
-            '0.2'
+            '0.2',
+            '1.0',
+            '1.1',
+            '1.2',
         ]
 
         self.raw = self._read_file(filename)
@@ -727,4 +733,4 @@ class TerraformParser(object):
         target_module = get_most_child_module(module)
         stripped_variable = variable.replace('var.', '')
         var = self.raw['configuration'].get('root_module', {}).get('module_calls', {}).get(target_module, {}).get('expressions', {}).get(stripped_variable, {}).get('references', {})
-        return var
\ No newline at end of file
+        return var
